@@ -1,4 +1,4 @@
-# $Id: ZapListings.pm,v 1.62 2003/09/13 19:34:56 epaepa Exp $
+# $Id: ZapListings.pm,v 1.64 2003/09/27 18:21:03 jveldhuis Exp $
 
 #
 # Special thanks to Stephen Bain for helping me play catch-up with
@@ -152,7 +152,7 @@ sub new
 				  env_proxy => 1,
 				  timeout => 180);
     bless ($self, $class);
-    $self->agent('xmltv/0.5.18');
+    $self->agent('xmltv/0.5.19');
     return $self;
 }
 
@@ -945,14 +945,16 @@ sub getChannelList($$)
     my $res=&doRequest($self->{ua}, $req, $self->{Debug});
     warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
     if ( !(   $res->is_success || $res->code eq '500') || $res->content()=~m/your session has timed out/i ) {
-	# again.
+	# again, but manditory sleep(5) between retries
+	sleep(5);
 	$res=&doRequest($self->{ua}, $req, $self->{Debug});
 
 	# looks like some requests require two identical calls since
 	# the zap2it server gives us a cookie that works with the second
 	# attempt after the first fails
 	if ( !$res->is_success || $res->content()=~m/your session has timed out/i ) {
-	    # again.
+	    # again, but manditory sleep(5) between retries
+	    sleep(5);
 	    $res=&doRequest($self->{ua}, $req, $self->{Debug});
 	}
     }
@@ -990,14 +992,16 @@ sub getChannelList($$)
 
     warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
     if ( !($res->is_success || $res->code eq '500') || $res->content()=~m/your session has timed out/i ) {
-	# again.
+	# again, but manditory sleep(5) between retries
+	sleep(5);
 	$res=&doRequest($self->{ua}, $req, $self->{Debug});
 
 	# looks like some requests require two identical calls since
 	# the zap2it server gives us a cookie that works with the second
 	# attempt after the first fails
 	if ( !$res->is_success || $res->content()=~m/your session has timed out/i ) {
-	    # again.
+	    # again, but manditory sleep(5) between retries
+	    sleep(5);
 	    $res=&doRequest($self->{ua}, $req, $self->{Debug});
 	}
     }
@@ -2120,12 +2124,13 @@ sub readSchedule($$$$$)
 	# attempt after the first fails
     warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
     if ( !($res->is_success || $res->code eq '500') || $res->content()=~m/your session has timed out/i ) {
-	    # again.
+	    # again, but manditory sleep(5) between retries
+	    sleep(5);
 	    $res=&doRequest($self->{ua}, $req, $self->{Debug});
 	}
 
 	warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
-    if ( !($res->is_success || $res->code eq '500') ) {
+	if ( !($res->is_success || $res->code eq '500') ) {
 	    warn("zap2it failed to give us a page: ".$res->code().":".
 			     HTTP::Status::status_message($res->code())."\n");
 	    warn("check postal/zip code or www site (maybe they're down)\n");
